Class to attach basic material data to 'mvdf_obj' objects
x,y,zNumeric: distance of the origin of the object from the origin of the grid system (the central point at 0, 0, 0) in meters in the given direction. Must have no 'NA', 'NULL', 'NaN', 'Inf', or '-Inf' values. Coordinates are assumed to be on a right-handed coordinate system with Z oriented as the natural "vertical" direction.
idxCharacter: a unique identifier (or "index") for each object to be modeled. Must be unique with no 'NA' or 'NULL' values, but otherwise is not validated.
metadataData frame: a table containing additional information on the objects to be modeled. Optional, but if this slot is used then the data frame must contain a column named 'idx' which should correspond to the 'idx' slot. Only the existence of this column is validated.
appendixList: additional data produced in the generation of the object. Not validated; any additional outputs that don't map to modeled objects may be inserted here.
diffuse_colorDiffuse color of the material, as an RGBA array of floats scaled from 0-1.
metallicAmount of mirror reflection for raytrace, as a float from 0-1.
roughnessRoughness of the material, as a float from 0-1.
Other classes and related functions:
mvdf_obj-class
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.